<?php
if (!defined('ABSPATH')) {
    exit;
}

// Function to get default settings
function hosting_security_get_defaults() {
    $defaults = [];
    foreach (hosting_security_get_available_features() as $feature_key => $feature_data) {
        $defaults[$feature_key] = 0; // Default all features to disabled
    }
    // Add default login hours restriction (disabled by default)
    $defaults['restrict-admin-login-hours'] = 0;
    $defaults['admin-login-start-time'] = '08:00';
    $defaults['admin-login-end-time'] = '18:00';
    // Add IP Whitelist feature
    $defaults['whitelist-ips'] = ''; // User input (comma-separated)
    return $defaults;
}

// Get current settings and merge with defaults
function hosting_security_get_settings() {
    $saved_settings = get_option('hosting_security_settings', []);
    return array_merge(hosting_security_get_defaults(), $saved_settings);
}

// Save settings when form is submitted
function hosting_security_save_settings() {
    if (!isset($_POST['hosting_security_nonce']) || !wp_verify_nonce($_POST['hosting_security_nonce'], 'hosting_security_save_settings')) {
        return;
    }
    if (!current_user_can('manage_options')) {
        return;
    }

    $new_settings = [];
    foreach (hosting_security_get_available_features() as $feature_key => $feature_data) {
        $new_settings[$feature_key] = isset($_POST[$feature_key]) ? 1 : 0;
    }

    // Store login restriction settings
    $new_settings['restrict-admin-login-hours'] = isset($_POST['restrict-admin-login-hours']) ? 1 : 0;
    $new_settings['admin-login-start-time'] = sanitize_text_field($_POST['admin-login-start-time']);
    $new_settings['admin-login-end-time'] = sanitize_text_field($_POST['admin-login-end-time']);

    // Store user-defined whitelist IPs
    $new_settings['whitelist-ips'] = sanitize_text_field($_POST['whitelist-ips']);

    update_option('hosting_security_settings', $new_settings);
}
add_action('admin_init', 'hosting_security_save_settings');

// Add settings page to admin menu
function hosting_security_add_settings_page() {
    add_menu_page('Hosting Security', 'Hosting Security', 'manage_options', 'hosting-security-settings', 'hosting_security_settings_page', 'dashicons-shield', 60);
}
add_action('admin_menu', 'hosting_security_add_settings_page');

// Settings Page Content
function hosting_security_settings_page() {
    $settings = hosting_security_get_settings();
    ?>
    <div class="wrap">
        <h1>Hosting Security Settings</h1>
        <form method="post">
            <?php wp_nonce_field('hosting_security_save_settings', 'hosting_security_nonce'); ?>
            <table class="form-table">
                <style>
                    .hs-toggle {
                        position: relative;
                        display: inline-block;
                        width: 50px;
                        height: 24px;
                    }
                    .hs-toggle input {
                        opacity: 0;
                        width: 0;
                        height: 0;
                    }
                    .hs-slider {
                        position: absolute;
                        cursor: pointer;
                        top: 0;
                        left: 0;
                        right: 0;
                        bottom: 0;
                        background-color: #ccc;
                        transition: 0.4s;
                        border-radius: 34px;
                    }
                    .hs-slider:before {
                        position: absolute;
                        content: "";
                        height: 18px;
                        width: 18px;
                        left: 3px;
                        bottom: 3px;
                        background-color: white;
                        transition: 0.4s;
                        border-radius: 50%;
                    }
                    input:checked + .hs-slider {
                        background-color: #4CAF50;
                    }
                    input:checked + .hs-slider:before {
                        transform: translateX(26px);
                    }
                </style>
                <?php foreach (hosting_security_get_available_features() as $feature_key => $feature_data): ?>
                    <tr>
                        <th><label for="<?php echo esc_attr($feature_key); ?>"><?php echo esc_html($feature_data['name']); ?></label></th>
                        <td>
                            <label class="hs-toggle">
                                <input type="checkbox" name="<?php echo esc_attr($feature_key); ?>" value="1" <?php checked($settings[$feature_key], 1); ?>>
                                <span class="hs-slider"></span>
                            </label>
                            <p class="description"><?php echo esc_html($feature_data['description']); ?></p>
                        </td>
                    </tr>

                    <!-- If Restrict Admin Login Hours is the current field, add time fields below it -->
                    <?php if ($feature_key === 'restrict-admin-login-hours'): ?>
                        <tr>
                            <th><label for="admin-login-start-time">Allowed Login Start Time</label></th>
                            <td><input type="time" name="admin-login-start-time" value="<?php echo esc_attr($settings['admin-login-start-time']); ?>"></td>
                        </tr>
                        <tr>
                            <th><label for="admin-login-end-time">Allowed Login End Time</label></th>
                            <td><input type="time" name="admin-login-end-time" value="<?php echo esc_attr($settings['admin-login-end-time']); ?>"></td>
                        </tr>
                    <?php endif; ?>
                <?php endforeach; ?>

                <!-- IP Whitelist Field -->
                <tr>
                    <th><label for="whitelist-ips">Whitelisted IPs</label></th>
                    <td>
                        <input type="text" name="whitelist-ips" value="<?php echo esc_attr($settings['whitelist-ips']); ?>" placeholder="Comma-separated IPs">
                        <p class="description">Add IP addresses to bypass security features. Example: 192.168.1.1, 203.0.113.45</p>
                    </td>
                </tr>

            </table>
            <p><input type="submit" class="button-primary" value="Save Changes"></p>
        </form>
    </div>
    <?php
}
function hosting_security_add_activation_page() {
    add_submenu_page(
        'hosting-security-settings',
        'Plugin Activation',
        'Activation',
        'manage_options',
        'hosting-security-activation',
        'hosting_security_activation_page'
    );
}
add_action('admin_menu', 'hosting_security_add_activation_page');

// Activation Page Content
function hosting_security_activation_page() {
    if (isset($_POST['reverify_domain']) && check_admin_referer('hosting_security_reverify')) {
        hosting_security_verify_domain();
    }

    $verified = get_option('hosting_security_verified', false);
    ?>
    <div class="wrap">
        <h1>Plugin Activation</h1>
        <p>Status: <strong><?php echo $verified ? '✅ Verified' : '❌ Not Verified'; ?></strong></p>
        <form method="post">
            <?php wp_nonce_field('hosting_security_reverify'); ?>
            <input type="submit" name="reverify_domain" class="button button-primary" value="Re-Verify Now">
        </form>
    </div>
    <?php
}
?>
